
Changelog
=========

0.2.3 (2015-06-18)
------------------

* Improved test suite
* Made some enums more explicit
* Aligned MUC room options with currently supported options in Ejabberd, build from master branch

0.2.2 (2015-05-25)
------------------

* Cleanup and more tests

0.2.1 (2015-05-25)
------------------

* Refactored method validator/serializer system


0.2.0 (2015-05-20)
------------------

* Big refactor, interface changed to better match the ejabberdctl interface.

0.1.2 (2015-05-16)
------------------

* Fixed build scripts.

0.1.1 (2015-05-16)
------------------

* Some bugfixes.

0.1.0 (2015-05-16)
------------------

* First release on PyPI.
